DBusMessageType

Enum DBusMessageType 

#[repr(C)]
pub enum DBusMessageType { Invalid = 0, MethodCall = 1, MethodReturn = 2, Error = 3, Signal = 4, }
One of the four different D-Bus message types.

Variants



Invalid = 0

This is not a valid message type (rarely used)



MethodCall = 1

This is a method call D-Bus message



MethodReturn = 2

This is a method return Ok D-Bus message, used when the method call message was successfully processed



Error = 3

This is a method return with error D-Bus message, used when the method call message could not be handled



Signal = 4

This is a signal, usually sent to whoever wants to listen